using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.Windows.Forms;

namespace PuzzlePlayer_Namespace
{
    internal class Program
    {
        internal static void Main(string[] args)
        {
            Application.Run(new MainForm());
        }
    }

    internal class MainForm : Form
    {
        List<PuzzleForm> puzzleForms = new List<PuzzleForm>();

        public MainForm()
        {
            SetUpPuzzleForms();
            SetUpUI();
        }

        private void SetUpPuzzleForms()
        {
            for (int i = 0; i < 5; i++)
            {
                puzzleForms.Add(new PuzzleForm(new Binary()));
            }
            puzzleForms.Add(new PuzzleForm(new Binary()));
        }

        private void SetUpUI()
        {
            // -- List<RoundedButton> buttons = new List<RoundedButton>();

            this.ClientSize = new Size(1115, 755);
            this.BackColor = SettingForm.primaryColor;
            this.Text = "PuzzlePlayer";

            MenuStrip menuStrip = new MenuStrip
            {
                BackColor = SettingForm.secondaryColor,
                ForeColor = SettingForm.secondaryColor,
                Name = "Main menu",
                Text = "Main Menu",
                Dock = DockStyle.Top,
                Font = SettingForm.mainFont,
            };

            ToolStripMenuItem menuSettings = new ToolStripMenuItem 
            {
                BackColor = Color.FromArgb(54, 57, 62),
                ForeColor = Color.Black,
                Text = "Settings",
                TextAlign = ContentAlignment.BottomRight,
                Font = SettingForm.mainFont,
            };

            menuSettings.Click += (object o, EventArgs e) =>
            {
                this.Hide();
                SettingForm settingForm = new SettingForm();

                settingForm.FormClosed += (object s, FormClosedEventArgs args) =>
                {
                    this.BackColor = SettingForm.primaryColor;
                    this.ForeColor = SettingForm.tertiaryColor;

                    foreach (Control control in this.Controls)
                    {
                        SettingForm.UpdateSettings(control);
                    }

                    this.Show();
                };

                settingForm.Show();
            };

            // Create a flow layout panel that automatically sorts the buttons when the window is resized
            FlowLayoutPanel buttonsPanel = new FlowLayoutPanel
            {
                Location = new Point(0, menuStrip.Height),
                Size = new Size(ClientSize.Width, ClientSize.Height - menuStrip.Height),
                Anchor = AnchorStyles.Top | AnchorStyles.Left | AnchorStyles.Right | AnchorStyles.Bottom,
                FlowDirection = FlowDirection.LeftToRight,
                // Add another row if there are more buttons than that fit in the window horizontally
                WrapContents = true,
                // Add a scroll bar in case the buttons don't fit on the window vertically
                AutoScroll = true,
            };

            // Add a button for each puzzle type
            for (int i = 0; i < puzzleForms.Count; i++)
            {
                string image = "../../..//Resources/" + $"{puzzleForms[i].puzzleType}";

                // Set the name of the button
                RoundedButton button = new RoundedButton
                {
                    Text = puzzleForms[i].puzzleType,
                    Margin = new Padding(10),
                    Height = 345,
                    Width = 345,
                    Image = Image.FromFile(image + ".jpg"),
                    FlatStyle = FlatStyle.Flat,
                    Font = SettingForm.mainFont,
                };

                button.MouseEnter += (object o, EventArgs e) =>
                {
                    button.Image = Image.FromFile(image + "Gray.jpg");
                };

                button.MouseLeave += (object o, EventArgs e) =>
                {
                    button.Image = Image.FromFile(image + ".jpg");
                };

                buttonsPanel.Controls.Add(button);
                // -- buttons.Add(button);

                if (i == 0)
                {
                    this.MinimumSize = new Size(button.Width + 56, button.Height + 83);
                }
            }
            this.Controls.Add(menuStrip);
            this.Controls.Add(buttonsPanel);

            menuStrip.Items.Add(menuSettings);
            menuStrip.BringToFront();
        }
    }
}

